import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

class AlphabetChildrenStyle extends Object {
  /// 已选文字颜色
  ///
  /// Selected text color
  final Color selectTextColor;

  /// 未选文字颜色
  ///
  /// Unselected text color
  final Color unSelectTextColor;

  /// 字体大小
  ///
  /// font size
  final double testSize;

  /// 已选背景色
  ///
  /// Selected background color
  final Color selectBackgroundColor;

  /// 未选背景色
  ///
  /// Selected background color
  final Color unSelectBackgroundColor;

  /// 子组件宽度
  ///
  /// Width of sub-component
  final double childWidth;

  /// 子组件高度
  ///
  /// Height of sub-component
  final double childHeight;

  /// 整体宽度
  ///
  /// Overall width
  final double totalWidth;

  /// 整体高度
  ///
  /// Overall height
  final double totalHeight;

  /// 整体背景色
  ///
  /// Overall background color
  final Color? childrenBackgroundColor;

  /// 在文本附近绘制的装饰（例如，下划线）。
  ///
  /// 可以使用 [TextDecoration.combine] 应用多种装饰
  /// The decorations to paint near the text (e.g., an underline).
  ///
  /// Multiple decorations can be applied using [TextDecoration.combine].
  final TextDecoration textDecoration;

  /// [EdgeInsets] 的基类，允许文本方向感知分辨率。
  ///
  /// 此类型的属性或参数接受使用 [new EdgeInsets.fromLTRB] 及其变体或
  /// [new EdgeInsetsDirectional.fromSTEB] 及其变体创建的类。
  ///
  /// 要将不确定类型的 [EdgeInsetsGeometry] 对象转换为 [EdgeInsets] 对象，
  /// 请调用 [resolve] 方法。
  ///
  /// Base class for [EdgeInsets] that allows for text-direction aware
  /// resolution.
  ///
  /// A property or argument of this type accepts classes created either with
  /// [new EdgeInsets.fromLTRB] and its variants, or [new
  /// EdgeInsetsDirectional.fromSTEB] and its variants.
  ///
  /// To convert an [EdgeInsetsGeometry] object of indeterminate type into a
  /// [EdgeInsets] object, call the [resolve] method.
  ///
  EdgeInsetsGeometry? margin;

  /// 二维中的两个基本方向。
  ///
  /// 轴总是相对于当前坐标空间。这意味着，例如，[horizontal] 轴实际上可能是从
  /// 右上角到左下角的对角线，这是由于对场景应用了一些局部 [Transform]。
  ///
  /// The two cardinal directions in two dimensions.
  ///
  /// The axis is always relative to the current coordinate space. This means, for
  /// example, that a [horizontal] axis might actually be diagonally from top
  /// right to bottom left, due to some local [Transform] applied to the scene.
  ///
  /// See also:
  ///
  ///  * [AxisDirection], which is a directional version of this enum (with values
  ///    light left and right, rather than just horizontal).
  ///  * [TextDirection], which disambiguates between left-to-right horizontal
  ///    content and right-to-left horizontal content.
  final Axis alphabetDirection;

  AlphabetChildrenStyle({
    this.childWidth = 16,
    this.childHeight = 16,
    this.totalWidth = 16,
    this.totalHeight = 450,
    this.margin,
    this.selectBackgroundColor = Colors.black,
    this.unSelectBackgroundColor = Colors.white,
    this.selectTextColor = Colors.white,
    this.unSelectTextColor = Colors.black,
    this.textDecoration = TextDecoration.none,
    this.alphabetDirection = Axis.vertical,
    this.childrenBackgroundColor,
    this.testSize = 10,
  });
}
